@@ -214,6 +214,75 @@ def strip_end(text, suffix):
     return text
 
 
+def windows_file_name(file_name):
+    '''
+        Strips (window's) invalid characters from the file_name.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_name` {str}
+            The string to be parsed.
+
+        Return {str}
+        ----------------------
+            The parsed string
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-19-2021 13:32:36
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: windows_file_name
+    '''
+    return re.sub(r'[<>:"/\|?*]*', "", file_name)
+
+
+def extension(string):
+    '''
+        Formats a file extension to have no leading period.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str|list}
+            The file extension or list of extensions to format
+
+        Keyword Arguments
+        -------------------------
+        `arg_name` {type}
+                arg_description
+
+        Return {str}
+        ----------------------
+        The formatted file extension
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-19-2021 13:33:51
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: extension
+    '''
+    new_ext_array = []
+    if isinstance(string, list) is False:
+        string = [string]
+
+    for ext in string:
+        # print(f"ext: {ext}")
+        ext = ext.lower()
+        ext = re.sub(r"^\.*", '', ext)
+        new_ext_array.append(ext)
+
+    if len(new_ext_array) == 1:
+        return new_ext_array[0]
+    return new_ext_array
+
+
 def file_path(value, **kwargs):
     '''
         Formats the path for use in windows.
